==> blockly-9.3.2.jar: META-INF/resources/webjars/blockly/9.3.2/core/events/events.d.ts <==
/**
 * @license
 * Copyright 2016 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import { Abstract, AbstractEventJson } from './events_abstract.js';
import { BlockBase, BlockBaseJson } from './events_block_base.js';
import { BlockChange, BlockChangeJson } from './events_block_change.js';
import { BlockCreate, BlockCreateJson } from './events_block_create.js';
import { BlockDelete, BlockDeleteJson } from './events_block_delete.js';
import { BlockDrag, BlockDragJson } from './events_block_drag.js';
import { BlockMove, BlockMoveJson } from './events_block_move.js';
import { BubbleOpen, BubbleOpenJson, BubbleType } from './events_bubble_open.js';
import { Click, ClickJson, ClickTarget } from './events_click.js';
import { CommentBase, CommentBaseJson } from './events_comment_base.js';
import { CommentChange, CommentChangeJson } from './events_comment_change.js';
import { CommentCreate, CommentCreateJson } from './events_comment_create.js';
import { CommentDelete } from './events_comment_delete.js';
import { CommentMove, CommentMoveJson } from './events_comment_move.js';
import { MarkerMove, MarkerMoveJson } from './events_marker_move.js';
import { Selected, SelectedJson } from './events_selected.js';
import { ThemeChange, ThemeChangeJson } from './events_theme_change.js';
import { ToolboxItemSelect, ToolboxItemSelectJson } from './events_toolbox_item_select.js';
import { TrashcanOpen, TrashcanOpenJson } from './events_trashcan_open.js';
import { Ui } from './events_ui.js';
import { UiBase } from './events_ui_base.js';
import { VarBase, VarBaseJson } from './events_var_base.js';
import { VarCreate, VarCreateJson } from './events_var_create.js';
import { VarDelete, VarDeleteJson } from './events_var_delete.js';
import { VarRename, VarRenameJson } from './events_var_rename.js';
import { ViewportChange, ViewportChangeJson } from './events_viewport.js';
import * as eventUtils from './utils.js';
import { FinishedLoading, FinishedLoadingJson } from './workspace_events.js';
export { Abstract };
export { AbstractEventJson };
export { BubbleOpen };
export { BubbleOpenJson };
export { BubbleType };
export { BlockBase };
export { BlockBaseJson };
export { BlockChange };
export { BlockChangeJson };
export { BlockCreate };
export { BlockCreateJson };
export { BlockDelete };
export { BlockDeleteJson };
export { BlockDrag };
export { BlockDragJson };
export { BlockMove };
export { BlockMoveJson };
export { Click };
export { ClickJson };
export { ClickTarget };
export { CommentBase };
export { CommentBaseJson };
export { CommentChange };
export { CommentChangeJson };
export { CommentCreate };
export { CommentCreateJson };
export { CommentDelete };
export { CommentMove };
export { CommentMoveJson };
export { FinishedLoading };
export { FinishedLoadingJson };
export { MarkerMove };
export { MarkerMoveJson };
export { Selected };
export { SelectedJson };
export { ThemeChange };
export { ThemeChangeJson };
export { ToolboxItemSelect };
export { ToolboxItemSelectJson };
export { TrashcanOpen };
export { TrashcanOpenJson };
export { Ui };
export { UiBase };
export { VarBase };
export { VarBaseJson };
export { VarCreate };
export { VarCreateJson };
export { VarDelete };
export { VarDeleteJson };
export { VarRename };
export { VarRenameJson };
export { ViewportChange };
export { ViewportChangeJson };
export declare const BLOCK_CHANGE = "change";
export declare const BLOCK_CREATE = "create";
export declare const BLOCK_DELETE = "delete";
export declare const BLOCK_DRAG = "drag";
export declare const BLOCK_MOVE = "move";
export declare const BUBBLE_OPEN = "bubble_open";
export type BumpEvent = eventUtils.BumpEvent;
export declare const BUMP_EVENTS: string[];
export declare const CHANGE = "change";
export declare const CLICK = "click";
export declare const COMMENT_CHANGE = "comment_change";
export declare const COMMENT_CREATE = "comment_create";
export declare const COMMENT_DELETE = "comment_delete";
export declare const COMMENT_MOVE = "comment_move";
export declare const CREATE = "create";
export declare const DELETE = "delete";
export declare const FINISHED_LOADING = "finished_loading";
export declare const MARKER_MOVE = "marker_move";
export declare const MOVE = "move";
export declare const SELECTED = "selected";
export declare const THEME_CHANGE = "theme_change";
export declare const TOOLBOX_ITEM_SELECT = "toolbox_item_select";
export declare const TRASHCAN_OPEN = "trashcan_open";
export declare const UI = "ui";
export declare const VAR_CREATE = "var_create";
export declare const VAR_DELETE = "var_delete";
export declare const VAR_RENAME = "var_rename";
export declare const VIEWPORT_CHANGE = "viewport_change";
export declare const clearPendingUndo: typeof eventUtils.clearPendingUndo;
export declare const disable: typeof eventUtils.disable;
export declare const enable: typeof eventUtils.enable;
export declare const filter: typeof eventUtils.filter;
export declare const fire: typeof eventUtils.fire;
export declare const fromJson: typeof eventUtils.fromJson;
export declare const getDescendantIds: typeof eventUtils.getDescendantIds;
export declare const get: typeof eventUtils.get;
export declare const getGroup: typeof eventUtils.getGroup;
export declare const getRecordUndo: typeof eventUtils.getRecordUndo;
export declare const isEnabled: typeof eventUtils.isEnabled;
export declare const setGroup: typeof eventUtils.setGroup;
export declare const setRecordUndo: typeof eventUtils.setRecordUndo;
export declare const disableOrphans: typeof eventUtils.disableOrphans;
//# sourceMappingURL=events.d.ts.map

==> blockly-10.4.1.jar: META-INF/resources/webjars/blockly/10.4.1/core/events/events.d.ts <==
/**
 * @license
 * Copyright 2016 Google LLC
 * SPDX-License-Identifier: Apache-2.0
 */
import { Abstract, AbstractEventJson } from './events_abstract.js';
import { BlockBase, BlockBaseJson } from './events_block_base.js';
import { BlockChange, BlockChangeJson } from './events_block_change.js';
import { BlockCreate, BlockCreateJson } from './events_block_create.js';
import { BlockDelete, BlockDeleteJson } from './events_block_delete.js';
import { BlockDrag, BlockDragJson } from './events_block_drag.js';
import { BlockFieldIntermediateChange, BlockFieldIntermediateChangeJson } from './events_block_field_intermediate_change.js';
import { BlockMove, BlockMoveJson } from './events_block_move.js';
import { BubbleOpen, BubbleOpenJson, BubbleType } from './events_bubble_open.js';
import { Click, ClickJson, ClickTarget } from './events_click.js';
import { CommentBase, CommentBaseJson } from './events_comment_base.js';
import { CommentChange, CommentChangeJson } from './events_comment_change.js';
import { CommentCreate, CommentCreateJson } from './events_comment_create.js';
import { CommentDelete } from './events_comment_delete.js';
import { CommentMove, CommentMoveJson } from './events_comment_move.js';
import { MarkerMove, MarkerMoveJson } from './events_marker_move.js';
import { Selected, SelectedJson } from './events_selected.js';
import { ThemeChange, ThemeChangeJson } from './events_theme_change.js';
import { ToolboxItemSelect, ToolboxItemSelectJson } from './events_toolbox_item_select.js';
import { TrashcanOpen, TrashcanOpenJson } from './events_trashcan_open.js';
import { UiBase } from './events_ui_base.js';
import { VarBase, VarBaseJson } from './events_var_base.js';
import { VarCreate, VarCreateJson } from './events_var_create.js';
import { VarDelete, VarDeleteJson } from './events_var_delete.js';
import { VarRename, VarRenameJson } from './events_var_rename.js';
import { ViewportChange, ViewportChangeJson } from './events_viewport.js';
import * as eventUtils from './utils.js';
import { FinishedLoading } from './workspace_events.js';
export { Abstract };
export { AbstractEventJson };
export { BubbleOpen };
export { BubbleOpenJson };
export { BubbleType };
export { BlockBase };
export { BlockBaseJson };
export { BlockChange };
export { BlockChangeJson };
export { BlockCreate };
export { BlockCreateJson };
export { BlockDelete };
export { BlockDeleteJson };
export { BlockDrag };
export { BlockDragJson };
export { BlockFieldIntermediateChange };
export { BlockFieldIntermediateChangeJson };
export { BlockMove };
export { BlockMoveJson };
export { Click };
export { ClickJson };
export { ClickTarget };
export { CommentBase };
export { CommentBaseJson };
export { CommentChange };
export { CommentChangeJson };
export { CommentCreate };
export { CommentCreateJson };
export { CommentDelete };
export { CommentMove };
export { CommentMoveJson };
export { FinishedLoading };
export { MarkerMove };
export { MarkerMoveJson };
export { Selected };
export { SelectedJson };
export { ThemeChange };
export { ThemeChangeJson };
export { ToolboxItemSelect };
export { ToolboxItemSelectJson };
export { TrashcanOpen };
export { TrashcanOpenJson };
export { UiBase };
export { VarBase };
export { VarBaseJson };
export { VarCreate };
export { VarCreateJson };
export { VarDelete };
export { VarDeleteJson };
export { VarRename };
export { VarRenameJson };
export { ViewportChange };
export { ViewportChangeJson };
export declare const BLOCK_CHANGE = "change";
export declare const BLOCK_CREATE = "create";
export declare const BLOCK_DELETE = "delete";
export declare const BLOCK_DRAG = "drag";
export declare const BLOCK_MOVE = "move";
export declare const BLOCK_FIELD_INTERMEDIATE_CHANGE = "block_field_intermediate_change";
export declare const BUBBLE_OPEN = "bubble_open";
export type BumpEvent = eventUtils.BumpEvent;
export declare const BUMP_EVENTS: string[];
export declare const CHANGE = "change";
export declare const CLICK = "click";
export declare const COMMENT_CHANGE = "comment_change";
export declare const COMMENT_CREATE = "comment_create";
export declare const COMMENT_DELETE = "comment_delete";
export declare const COMMENT_MOVE = "comment_move";
export declare const CREATE = "create";
export declare const DELETE = "delete";
export declare const FINISHED_LOADING = "finished_loading";
export declare const MARKER_MOVE = "marker_move";
export declare const MOVE = "move";
export declare const SELECTED = "selected";
export declare const THEME_CHANGE = "theme_change";
export declare const TOOLBOX_ITEM_SELECT = "toolbox_item_select";
export declare const TRASHCAN_OPEN = "trashcan_open";
export declare const UI = "ui";
export declare const VAR_CREATE = "var_create";
export declare const VAR_DELETE = "var_delete";
export declare const VAR_RENAME = "var_rename";
export declare const VIEWPORT_CHANGE = "viewport_change";
export declare const clearPendingUndo: typeof eventUtils.clearPendingUndo;
export declare const disable: typeof eventUtils.disable;
export declare const enable: typeof eventUtils.enable;
export declare const filter: typeof eventUtils.filter;
export declare const fire: typeof eventUtils.fire;
export declare const fromJson: typeof eventUtils.fromJson;
export declare const getDescendantIds: typeof eventUtils.getDescendantIds;
export declare const get: typeof eventUtils.get;
export declare const getGroup: typeof eventUtils.getGroup;
export declare const getRecordUndo: typeof eventUtils.getRecordUndo;
export declare const isEnabled: typeof eventUtils.isEnabled;
export declare const setGroup: typeof eventUtils.setGroup;
export declare const setRecordUndo: typeof eventUtils.setRecordUndo;
export declare const disableOrphans: typeof eventUtils.disableOrphans;
//# sourceMappingURL=events.d.ts.map
